/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>

#include <gnome.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

GtkWidget*
create_window1 (void)
{
  GtkWidget *window1;
  GtkWidget *vbox1;
  GtkWidget *packer1;
  GtkWidget *lblHostname;
  GtkWidget *comboHostname;
  GtkWidget *txtHostname;
  GtkWidget *packer2;
  GtkWidget *lblUsername;
  GtkWidget *txtUsername;
  GtkWidget *packer3;
  GtkWidget *chkPort;
  GtkObject *txtPort_adj;
  GtkWidget *txtPort;
  GtkWidget *btnOptions;
  GtkWidget *packer4;
  GtkWidget *btnConnect;
  GtkWidget *btnAbout;
  GtkWidget *btnQuit;

  window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_object_set_data (GTK_OBJECT (window1), "window1", window1);
  gtk_widget_set_usize (window1, 263, 142);
  gtk_window_set_title (GTK_WINDOW (window1), _("gssh"));

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox1);
  gtk_object_set_data_full (GTK_OBJECT (window1), "vbox1", vbox1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (window1), vbox1);

  packer1 = gtk_packer_new ();
  gtk_widget_ref (packer1);
  gtk_object_set_data_full (GTK_OBJECT (window1), "packer1", packer1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (packer1);
  gtk_box_pack_start (GTK_BOX (vbox1), packer1, TRUE, TRUE, 0);

  lblHostname = gtk_label_new (_("Hostname:"));
  gtk_widget_ref (lblHostname);
  gtk_object_set_data_full (GTK_OBJECT (window1), "lblHostname", lblHostname,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lblHostname);
  gtk_packer_add (GTK_PACKER (packer1), lblHostname, GTK_SIDE_LEFT,
                  GTK_ANCHOR_CENTER, (GtkPackerOptions) (0),
                  0, 5, 0, 0, 0);

  comboHostname = gtk_combo_new ();
  gtk_widget_ref (comboHostname);
  gtk_object_set_data_full (GTK_OBJECT (window1), "comboHostname", comboHostname,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (comboHostname);
  gtk_packer_add (GTK_PACKER (packer1), comboHostname, GTK_SIDE_RIGHT,
                  GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X),
                  0, 5, 0, 0, 0);

  txtHostname = GTK_COMBO (comboHostname)->entry;
  gtk_widget_ref (txtHostname);
  gtk_object_set_data_full (GTK_OBJECT (window1), "txtHostname", txtHostname,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtHostname);
  gtk_entry_set_text (GTK_ENTRY (txtHostname), _("localhost"));

  packer2 = gtk_packer_new ();
  gtk_widget_ref (packer2);
  gtk_object_set_data_full (GTK_OBJECT (window1), "packer2", packer2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (packer2);
  gtk_box_pack_start (GTK_BOX (vbox1), packer2, TRUE, TRUE, 0);

  lblUsername = gtk_label_new (_("Username:"));
  gtk_widget_ref (lblUsername);
  gtk_object_set_data_full (GTK_OBJECT (window1), "lblUsername", lblUsername,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lblUsername);
  gtk_packer_add (GTK_PACKER (packer2), lblUsername, GTK_SIDE_LEFT,
                  GTK_ANCHOR_CENTER, (GtkPackerOptions) (0),
                  0, 5, 0, 0, 0);

  txtUsername = gtk_entry_new ();
  gtk_widget_ref (txtUsername);
  gtk_object_set_data_full (GTK_OBJECT (window1), "txtUsername", txtUsername,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtUsername);
  gtk_packer_add (GTK_PACKER (packer2), txtUsername, GTK_SIDE_RIGHT,
                  GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X),
                  0, 5, 0, 0, 0);

  packer3 = gtk_packer_new ();
  gtk_widget_ref (packer3);
  gtk_object_set_data_full (GTK_OBJECT (window1), "packer3", packer3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (packer3);
  gtk_box_pack_start (GTK_BOX (vbox1), packer3, TRUE, TRUE, 0);

  chkPort = gtk_check_button_new_with_label (_("Use port:"));
  gtk_widget_ref (chkPort);
  gtk_object_set_data_full (GTK_OBJECT (window1), "chkPort", chkPort,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkPort);
  gtk_packer_add (GTK_PACKER (packer3), chkPort, GTK_SIDE_LEFT,
                  GTK_ANCHOR_CENTER, (GtkPackerOptions) (0),
                  0, 5, 0, 0, 0);

  txtPort_adj = gtk_adjustment_new (22, 1, 9999, 1, 10, 10);
  txtPort = gtk_spin_button_new (GTK_ADJUSTMENT (txtPort_adj), 1, 0);
  gtk_widget_ref (txtPort);
  gtk_object_set_data_full (GTK_OBJECT (window1), "txtPort", txtPort,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtPort);
  gtk_packer_add (GTK_PACKER (packer3), txtPort, GTK_SIDE_LEFT,
                  GTK_ANCHOR_CENTER, (GtkPackerOptions) (0),
                  0, 5, 0, 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (txtPort), TRUE);

  btnOptions = gtk_button_new_with_label (_("Options"));
  gtk_widget_ref (btnOptions);
  gtk_object_set_data_full (GTK_OBJECT (window1), "btnOptions", btnOptions,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnOptions);
  gtk_packer_add (GTK_PACKER (packer3), btnOptions, GTK_SIDE_TOP,
                  GTK_ANCHOR_EAST, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_Y),
                  0, 54, 3, 0, 0);
  gtk_widget_set_usize (btnOptions, 91, 27);

  packer4 = gtk_packer_new ();
  gtk_widget_ref (packer4);
  gtk_object_set_data_full (GTK_OBJECT (window1), "packer4", packer4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (packer4);
  gtk_box_pack_start (GTK_BOX (vbox1), packer4, TRUE, TRUE, 0);

  btnConnect = gtk_button_new_with_label (_("Connect"));
  gtk_widget_ref (btnConnect);
  gtk_object_set_data_full (GTK_OBJECT (window1), "btnConnect", btnConnect,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnConnect);
  gtk_packer_add_defaults (GTK_PACKER (packer4), btnConnect, GTK_SIDE_LEFT,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X | GTK_FILL_Y));

  btnAbout = gtk_button_new_with_label (_("About gssh"));
  gtk_widget_ref (btnAbout);
  gtk_object_set_data_full (GTK_OBJECT (window1), "btnAbout", btnAbout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnAbout);
  gtk_packer_add_defaults (GTK_PACKER (packer4), btnAbout, GTK_SIDE_LEFT,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X | GTK_FILL_Y));

  btnQuit = gtk_button_new_with_label (_("Quit"));
  gtk_widget_ref (btnQuit);
  gtk_object_set_data_full (GTK_OBJECT (window1), "btnQuit", btnQuit,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnQuit);
  gtk_packer_add_defaults (GTK_PACKER (packer4), btnQuit, GTK_SIDE_LEFT,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X | GTK_FILL_Y));

  gtk_signal_connect (GTK_OBJECT (window1), "destroy",
                      GTK_SIGNAL_FUNC (gtk_main_quit),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (txtHostname), "changed",
                      GTK_SIGNAL_FUNC (on_txtHostname_changed),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnOptions), "clicked",
                      GTK_SIGNAL_FUNC (on_btnOptions_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnConnect), "clicked",
                      GTK_SIGNAL_FUNC (on_btnConnect_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnAbout), "clicked",
                      GTK_SIGNAL_FUNC (on_btnAbout_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnQuit), "clicked",
                      GTK_SIGNAL_FUNC (exit_app),
                      NULL);

  return window1;
}

GtkWidget*
create_dlgAbout (void)
{
  const gchar *authors[] = {
    "Calle Laakkonen",
    NULL
  };
  GtkWidget *dlgAbout;

  dlgAbout = gnome_about_new ("Gssh", VERSION,
                        "",
                        authors,
                        _("A front end to ssh.\nAppearance made to mimic kssh"),
                        "gssh/gssh_logo.png");
  gtk_object_set_data (GTK_OBJECT (dlgAbout), "dlgAbout", dlgAbout);
  gtk_window_set_modal (GTK_WINDOW (dlgAbout), TRUE);

  return dlgAbout;
}

GtkWidget*
create_window2 (void)
{
  GtkWidget *window2;
  GtkWidget *vbox2;
  GtkWidget *hbox1;
  GtkWidget *packer5;
  GtkWidget *lblHost;
  GtkWidget *txtAddHost;
  GtkWidget *scrolledwindow1;
  GtkWidget *lstHosts;
  GtkWidget *label5;
  GtkWidget *packer6;
  GtkWidget *btnAdd;
  GtkWidget *btnRemove;
  GtkWidget *btnUp;
  GtkWidget *btnDown;
  GtkWidget *btnHostSettings;
  GtkWidget *vbox3;
  GtkWidget *packer7;
  GtkWidget *hseparator1;
  GtkWidget *lblSshCmd;
  GtkWidget *txtSsh;
  GtkWidget *packer8;
  GtkWidget *lblTerm;
  GtkWidget *txtTerminal;
  GtkWidget *hbox2;
  GtkWidget *packer9;
  GtkWidget *chkSaveHostName;
  GtkWidget *chkSaveHostSettings;
  GtkWidget *chkUseHostSettings;
  GtkWidget *packer11;
  GSList *packer11_group = NULL;
  GtkWidget *chkReplace;
  GtkWidget *chkAppend;
  GtkWidget *btnImport;
  GtkWidget *packer10;
  GtkWidget *btnOkConf;
  GtkWidget *btnCancelConf;

  window2 = gtk_window_new (GTK_WINDOW_DIALOG);
  gtk_object_set_data (GTK_OBJECT (window2), "window2", window2);
  gtk_widget_set_usize (window2, 343, 372);
  gtk_window_set_title (GTK_WINDOW (window2), _("gssh options"));

  vbox2 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox2);
  gtk_object_set_data_full (GTK_OBJECT (window2), "vbox2", vbox2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox2);
  gtk_container_add (GTK_CONTAINER (window2), vbox2);

  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_widget_ref (hbox1);
  gtk_object_set_data_full (GTK_OBJECT (window2), "hbox1", hbox1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vbox2), hbox1, TRUE, TRUE, 0);

  packer5 = gtk_packer_new ();
  gtk_widget_ref (packer5);
  gtk_object_set_data_full (GTK_OBJECT (window2), "packer5", packer5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (packer5);
  gtk_box_pack_start (GTK_BOX (hbox1), packer5, TRUE, TRUE, 0);

  lblHost = gtk_label_new (_("Host"));
  gtk_widget_ref (lblHost);
  gtk_object_set_data_full (GTK_OBJECT (window2), "lblHost", lblHost,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lblHost);
  gtk_packer_add (GTK_PACKER (packer5), lblHost, GTK_SIDE_TOP,
                  GTK_ANCHOR_WEST, (GtkPackerOptions) (0),
                  0, 10, 6, 0, 0);

  txtAddHost = gtk_entry_new ();
  gtk_widget_ref (txtAddHost);
  gtk_object_set_data_full (GTK_OBJECT (window2), "txtAddHost", txtAddHost,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtAddHost);
  gtk_packer_add (GTK_PACKER (packer5), txtAddHost, GTK_SIDE_TOP,
                  GTK_ANCHOR_NORTH_WEST, (GtkPackerOptions) (GTK_FILL_X),
                  0, 10, 0, 0, 0);

  scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_ref (scrolledwindow1);
  gtk_object_set_data_full (GTK_OBJECT (window2), "scrolledwindow1", scrolledwindow1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow1);
  gtk_packer_add (GTK_PACKER (packer5), scrolledwindow1, GTK_SIDE_TOP,
                  GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X | GTK_FILL_Y),
                  0, 10, 6, 0, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);

  lstHosts = gtk_clist_new (1);
  gtk_widget_ref (lstHosts);
  gtk_object_set_data_full (GTK_OBJECT (window2), "lstHosts", lstHosts,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lstHosts);
  gtk_container_add (GTK_CONTAINER (scrolledwindow1), lstHosts);
  gtk_clist_set_column_width (GTK_CLIST (lstHosts), 0, 80);
  gtk_clist_column_titles_show (GTK_CLIST (lstHosts));

  label5 = gtk_label_new (_("Host list"));
  gtk_widget_ref (label5);
  gtk_object_set_data_full (GTK_OBJECT (window2), "label5", label5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label5);
  gtk_clist_set_column_widget (GTK_CLIST (lstHosts), 0, label5);
  gtk_label_set_justify (GTK_LABEL (label5), GTK_JUSTIFY_LEFT);

  packer6 = gtk_packer_new ();
  gtk_packer_set_default_pad (GTK_PACKER (packer6), 4, 12);
  gtk_widget_ref (packer6);
  gtk_object_set_data_full (GTK_OBJECT (window2), "packer6", packer6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (packer6);
  gtk_box_pack_start (GTK_BOX (hbox1), packer6, TRUE, TRUE, 0);

  btnAdd = gtk_button_new_with_label (_("Add"));
  gtk_widget_ref (btnAdd);
  gtk_object_set_data_full (GTK_OBJECT (window2), "btnAdd", btnAdd,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnAdd);
  gtk_packer_add_defaults (GTK_PACKER (packer6), btnAdd, GTK_SIDE_TOP,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X | GTK_FILL_Y));

  btnRemove = gtk_button_new_with_label (_("Remove"));
  gtk_widget_ref (btnRemove);
  gtk_object_set_data_full (GTK_OBJECT (window2), "btnRemove", btnRemove,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnRemove);
  gtk_packer_add_defaults (GTK_PACKER (packer6), btnRemove, GTK_SIDE_TOP,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X | GTK_FILL_Y));

  btnUp = gnome_stock_button (GNOME_STOCK_BUTTON_UP);
  gtk_widget_ref (btnUp);
  gtk_object_set_data_full (GTK_OBJECT (window2), "btnUp", btnUp,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnUp);
  gtk_packer_add_defaults (GTK_PACKER (packer6), btnUp, GTK_SIDE_TOP,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X | GTK_FILL_Y));

  btnDown = gnome_stock_button (GNOME_STOCK_BUTTON_DOWN);
  gtk_widget_ref (btnDown);
  gtk_object_set_data_full (GTK_OBJECT (window2), "btnDown", btnDown,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnDown);
  gtk_packer_add_defaults (GTK_PACKER (packer6), btnDown, GTK_SIDE_TOP,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X | GTK_FILL_Y));

  btnHostSettings = gtk_button_new_with_label (_("Host settings"));
  gtk_widget_ref (btnHostSettings);
  gtk_object_set_data_full (GTK_OBJECT (window2), "btnHostSettings", btnHostSettings,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnHostSettings);
  gtk_packer_add_defaults (GTK_PACKER (packer6), btnHostSettings, GTK_SIDE_TOP,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X | GTK_FILL_Y));

  vbox3 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox3);
  gtk_object_set_data_full (GTK_OBJECT (window2), "vbox3", vbox3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox3);
  gtk_box_pack_start (GTK_BOX (vbox2), vbox3, TRUE, TRUE, 0);

  packer7 = gtk_packer_new ();
  gtk_packer_set_default_pad (GTK_PACKER (packer7), 35, 0);
  gtk_widget_ref (packer7);
  gtk_object_set_data_full (GTK_OBJECT (window2), "packer7", packer7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (packer7);
  gtk_box_pack_start (GTK_BOX (vbox3), packer7, TRUE, TRUE, 0);

  hseparator1 = gtk_hseparator_new ();
  gtk_widget_ref (hseparator1);
  gtk_object_set_data_full (GTK_OBJECT (window2), "hseparator1", hseparator1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator1);
  gtk_packer_add (GTK_PACKER (packer7), hseparator1, GTK_SIDE_TOP,
                  GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_FILL_X),
                  0, 28, 5, 0, 0);
  gtk_widget_set_usize (hseparator1, -2, 2);

  lblSshCmd = gtk_label_new (_("Ssh command:"));
  gtk_widget_ref (lblSshCmd);
  gtk_object_set_data_full (GTK_OBJECT (window2), "lblSshCmd", lblSshCmd,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lblSshCmd);
  gtk_packer_add_defaults (GTK_PACKER (packer7), lblSshCmd, GTK_SIDE_TOP,
                           GTK_ANCHOR_WEST, (GtkPackerOptions) (0));

  txtSsh = gtk_entry_new ();
  gtk_widget_ref (txtSsh);
  gtk_object_set_data_full (GTK_OBJECT (window2), "txtSsh", txtSsh,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtSsh);
  gtk_packer_add_defaults (GTK_PACKER (packer7), txtSsh, GTK_SIDE_LEFT,
                           GTK_ANCHOR_NORTH, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X));
  gtk_entry_set_text (GTK_ENTRY (txtSsh), _("ssh"));

  packer8 = gtk_packer_new ();
  gtk_packer_set_default_pad (GTK_PACKER (packer8), 35, 0);
  gtk_widget_ref (packer8);
  gtk_object_set_data_full (GTK_OBJECT (window2), "packer8", packer8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (packer8);
  gtk_box_pack_start (GTK_BOX (vbox3), packer8, TRUE, TRUE, 0);

  lblTerm = gtk_label_new (_("Terminal"));
  gtk_widget_ref (lblTerm);
  gtk_object_set_data_full (GTK_OBJECT (window2), "lblTerm", lblTerm,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lblTerm);
  gtk_packer_add_defaults (GTK_PACKER (packer8), lblTerm, GTK_SIDE_TOP,
                           GTK_ANCHOR_WEST, (GtkPackerOptions) (0));

  txtTerminal = gtk_entry_new ();
  gtk_widget_ref (txtTerminal);
  gtk_object_set_data_full (GTK_OBJECT (window2), "txtTerminal", txtTerminal,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtTerminal);
  gtk_packer_add_defaults (GTK_PACKER (packer8), txtTerminal, GTK_SIDE_LEFT,
                           GTK_ANCHOR_NORTH, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X));
  gtk_entry_set_text (GTK_ENTRY (txtTerminal), _("gnome-terminal"));

  hbox2 = gtk_hbox_new (FALSE, 0);
  gtk_widget_ref (hbox2);
  gtk_object_set_data_full (GTK_OBJECT (window2), "hbox2", hbox2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2);
  gtk_box_pack_start (GTK_BOX (vbox2), hbox2, TRUE, TRUE, 0);

  packer9 = gtk_packer_new ();
  gtk_packer_set_default_pad (GTK_PACKER (packer9), 35, 0);
  gtk_widget_ref (packer9);
  gtk_object_set_data_full (GTK_OBJECT (window2), "packer9", packer9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (packer9);
  gtk_box_pack_start (GTK_BOX (hbox2), packer9, TRUE, TRUE, 0);

  chkSaveHostName = gtk_check_button_new_with_label (_("Save host name"));
  gtk_widget_ref (chkSaveHostName);
  gtk_object_set_data_full (GTK_OBJECT (window2), "chkSaveHostName", chkSaveHostName,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkSaveHostName);
  gtk_packer_add_defaults (GTK_PACKER (packer9), chkSaveHostName, GTK_SIDE_TOP,
                           GTK_ANCHOR_WEST, (GtkPackerOptions) (0));
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkSaveHostName), TRUE);

  chkSaveHostSettings = gtk_check_button_new_with_label (_("Save host settings"));
  gtk_widget_ref (chkSaveHostSettings);
  gtk_object_set_data_full (GTK_OBJECT (window2), "chkSaveHostSettings", chkSaveHostSettings,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkSaveHostSettings);
  gtk_packer_add_defaults (GTK_PACKER (packer9), chkSaveHostSettings, GTK_SIDE_TOP,
                           GTK_ANCHOR_WEST, (GtkPackerOptions) (0));
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkSaveHostSettings), TRUE);

  chkUseHostSettings = gtk_check_button_new_with_label (_("Use host settings"));
  gtk_widget_ref (chkUseHostSettings);
  gtk_object_set_data_full (GTK_OBJECT (window2), "chkUseHostSettings", chkUseHostSettings,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkUseHostSettings);
  gtk_packer_add_defaults (GTK_PACKER (packer9), chkUseHostSettings, GTK_SIDE_LEFT,
                           GTK_ANCHOR_NORTH, (GtkPackerOptions) (0));
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkUseHostSettings), TRUE);

  packer11 = gtk_packer_new ();
  gtk_widget_ref (packer11);
  gtk_object_set_data_full (GTK_OBJECT (window2), "packer11", packer11,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (packer11);
  gtk_box_pack_start (GTK_BOX (hbox2), packer11, TRUE, TRUE, 0);

  chkReplace = gtk_radio_button_new_with_label (packer11_group, _("Replace"));
  packer11_group = gtk_radio_button_group (GTK_RADIO_BUTTON (chkReplace));
  gtk_widget_ref (chkReplace);
  gtk_object_set_data_full (GTK_OBJECT (window2), "chkReplace", chkReplace,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkReplace);
  gtk_packer_add_defaults (GTK_PACKER (packer11), chkReplace, GTK_SIDE_TOP,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (0));

  chkAppend = gtk_radio_button_new_with_label (packer11_group, _("Append"));
  packer11_group = gtk_radio_button_group (GTK_RADIO_BUTTON (chkAppend));
  gtk_widget_ref (chkAppend);
  gtk_object_set_data_full (GTK_OBJECT (window2), "chkAppend", chkAppend,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkAppend);
  gtk_packer_add_defaults (GTK_PACKER (packer11), chkAppend, GTK_SIDE_TOP,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (0));
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (chkAppend), TRUE);

  btnImport = gtk_button_new_with_label (_("Import from kssh"));
  gtk_widget_ref (btnImport);
  gtk_object_set_data_full (GTK_OBJECT (window2), "btnImport", btnImport,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnImport);
  gtk_packer_add_defaults (GTK_PACKER (packer11), btnImport, GTK_SIDE_TOP,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (0));

  packer10 = gtk_packer_new ();
  gtk_packer_set_default_pad (GTK_PACKER (packer10), 57, 10);
  gtk_widget_ref (packer10);
  gtk_object_set_data_full (GTK_OBJECT (window2), "packer10", packer10,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (packer10);
  gtk_box_pack_start (GTK_BOX (vbox2), packer10, TRUE, TRUE, 0);

  btnOkConf = gnome_stock_button (GNOME_STOCK_BUTTON_OK);
  gtk_widget_ref (btnOkConf);
  gtk_object_set_data_full (GTK_OBJECT (window2), "btnOkConf", btnOkConf,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnOkConf);
  gtk_packer_add_defaults (GTK_PACKER (packer10), btnOkConf, GTK_SIDE_LEFT,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X));

  btnCancelConf = gnome_stock_button (GNOME_STOCK_BUTTON_CANCEL);
  gtk_widget_ref (btnCancelConf);
  gtk_object_set_data_full (GTK_OBJECT (window2), "btnCancelConf", btnCancelConf,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnCancelConf);
  gtk_packer_add_defaults (GTK_PACKER (packer10), btnCancelConf, GTK_SIDE_RIGHT,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X));

  gtk_signal_connect (GTK_OBJECT (window2), "delete_event",
                      GTK_SIGNAL_FUNC (on_window_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (lstHosts), "select_row",
                      GTK_SIGNAL_FUNC (on_lstHosts_select_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnAdd), "clicked",
                      GTK_SIGNAL_FUNC (on_btnAdd_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnRemove), "clicked",
                      GTK_SIGNAL_FUNC (on_btnRemove_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnUp), "clicked",
                      GTK_SIGNAL_FUNC (on_btnUp_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnDown), "clicked",
                      GTK_SIGNAL_FUNC (on_btnDown_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnHostSettings), "clicked",
                      GTK_SIGNAL_FUNC (on_btnHostSettings_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnImport), "clicked",
                      GTK_SIGNAL_FUNC (on_btnImport_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnOkConf), "clicked",
                      GTK_SIGNAL_FUNC (on_btnOkConf_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnCancelConf), "clicked",
                      GTK_SIGNAL_FUNC (on_btnCancelConf_clicked),
                      NULL);

  return window2;
}

GtkWidget*
create_window3 (void)
{
  GtkWidget *window3;
  GtkWidget *packer12;
  GtkWidget *notebook1;
  GtkWidget *table1;
  GtkWidget *label10;
  GtkWidget *label13;
  GtkWidget *btnSettingsUsePort;
  GtkWidget *txtSettingsUsername;
  GtkObject *txtSettingsPort_adj;
  GtkWidget *txtSettingsPort;
  GtkWidget *chkEnableExtra;
  GtkWidget *label34;
  GtkWidget *label8;
  GtkWidget *vbox5;
  GtkWidget *table2;
  GtkWidget *btnForwardLocal;
  GtkWidget *label14;
  GtkWidget *btnForwardRemote;
  GtkWidget *txtForwardRemote;
  GtkWidget *txtForwardLocal;
  GtkObject *txtForwardRemotePort_adj;
  GtkWidget *txtForwardRemotePort;
  GtkObject *txtForwardLocalPort_adj;
  GtkWidget *txtForwardLocalPort;
  GtkWidget *label16;
  GtkWidget *label15;
  GtkWidget *label33;
  GtkObject *txtForwardLocalPortC_adj;
  GtkWidget *txtForwardLocalPortC;
  GtkObject *txtForwardRemotePortC_adj;
  GtkWidget *txtForwardRemotePortC;
  GtkWidget *table3;
  GtkWidget *label17;
  GtkWidget *label18;
  GtkWidget *lstX11Forward;
  GList *lstX11Forward_items = NULL;
  GtkWidget *txtX11;
  GtkWidget *lstAuthForward;
  GList *lstAuthForward_items = NULL;
  GtkWidget *txtAuth;
  GtkWidget *label19;
  GtkWidget *chkAllowRemote;
  GtkWidget *label23;
  GtkWidget *chkDisableKerberos;
  GtkWidget *label9;
  GtkWidget *table4;
  GtkWidget *label21;
  GtkWidget *lstCipherType;
  GList *lstCipherType_items = NULL;
  GtkWidget *txtCipher;
  GtkWidget *togglebutton4;
  GtkWidget *txtEscape;
  GtkWidget *label22;
  GtkWidget *txtIdFile;
  GtkWidget *txtIdent;
  GtkWidget *label24;
  GtkWidget *chkNonprivPort;
  GtkWidget *label25;
  GtkWidget *lstPseudoTty;
  GList *lstPseudoTty_items = NULL;
  GtkWidget *txtPseudoTTY;
  GtkWidget *label26;
  GtkWidget *chkCompression;
  GtkWidget *label27;
  GtkWidget *txtCustom;
  GtkWidget *label20;
  GtkWidget *table5;
  GtkWidget *label29;
  GtkWidget *chkFork;
  GtkWidget *label30;
  GtkWidget *chkDevNull;
  GtkWidget *label31;
  GtkWidget *chkExecCmd;
  GtkWidget *label32;
  GtkWidget *txtExecCmd;
  GtkWidget *label28;
  GtkWidget *btnSettingsOk;
  GtkWidget *btnSettingsCancel;

  window3 = gtk_window_new (GTK_WINDOW_DIALOG);
  gtk_object_set_data (GTK_OBJECT (window3), "window3", window3);
  gtk_window_set_title (GTK_WINDOW (window3), _("Settings"));

  packer12 = gtk_packer_new ();
  gtk_widget_ref (packer12);
  gtk_object_set_data_full (GTK_OBJECT (window3), "packer12", packer12,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (packer12);
  gtk_container_add (GTK_CONTAINER (window3), packer12);

  notebook1 = gtk_notebook_new ();
  gtk_widget_ref (notebook1);
  gtk_object_set_data_full (GTK_OBJECT (window3), "notebook1", notebook1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (notebook1);
  gtk_packer_add_defaults (GTK_PACKER (packer12), notebook1, GTK_SIDE_TOP,
                           GTK_ANCHOR_CENTER, (GtkPackerOptions) (GTK_PACK_EXPAND | GTK_FILL_X | GTK_FILL_Y));

  table1 = gtk_table_new (4, 2, FALSE);
  gtk_widget_ref (table1);
  gtk_object_set_data_full (GTK_OBJECT (window3), "table1", table1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table1);
  gtk_container_add (GTK_CONTAINER (notebook1), table1);

  label10 = gtk_label_new (_("Username      "));
  gtk_widget_ref (label10);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label10", label10,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label10);
  gtk_table_attach (GTK_TABLE (table1), label10, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label10), 0, 0.5);

  label13 = gtk_label_new (_("Extra settings"));
  gtk_widget_ref (label13);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label13", label13,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label13);
  gtk_table_attach (GTK_TABLE (table1), label13, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label13), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label13), 0, 0.5);

  btnSettingsUsePort = gtk_toggle_button_new_with_label (_("Use port"));
  gtk_widget_ref (btnSettingsUsePort);
  gtk_object_set_data_full (GTK_OBJECT (window3), "btnSettingsUsePort", btnSettingsUsePort,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnSettingsUsePort);
  gtk_table_attach (GTK_TABLE (table1), btnSettingsUsePort, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_button_set_relief (GTK_BUTTON (btnSettingsUsePort), GTK_RELIEF_NONE);

  txtSettingsUsername = gtk_entry_new ();
  gtk_widget_ref (txtSettingsUsername);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtSettingsUsername", txtSettingsUsername,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtSettingsUsername);
  gtk_table_attach (GTK_TABLE (table1), txtSettingsUsername, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  txtSettingsPort_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  txtSettingsPort = gtk_spin_button_new (GTK_ADJUSTMENT (txtSettingsPort_adj), 1, 0);
  gtk_widget_ref (txtSettingsPort);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtSettingsPort", txtSettingsPort,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtSettingsPort);
  gtk_table_attach (GTK_TABLE (table1), txtSettingsPort, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (txtSettingsPort), TRUE);

  chkEnableExtra = gtk_check_button_new_with_label (_("Enable"));
  gtk_widget_ref (chkEnableExtra);
  gtk_object_set_data_full (GTK_OBJECT (window3), "chkEnableExtra", chkEnableExtra,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkEnableExtra);
  gtk_table_attach (GTK_TABLE (table1), chkEnableExtra, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label34 = gtk_label_new (_("Note ! If you want to use the extra\nfeatures on the other pages, be sure to\nenable the 'Extra settings' checkbox above !"));
  gtk_widget_ref (label34);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label34", label34,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label34);
  gtk_table_attach (GTK_TABLE (table1), label34, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label34), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label34), 0, 0.5);

  label8 = gtk_label_new (_("Basic"));
  gtk_widget_ref (label8);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label8", label8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 0), label8);

  vbox5 = gtk_vbox_new (FALSE, 0);
  gtk_widget_ref (vbox5);
  gtk_object_set_data_full (GTK_OBJECT (window3), "vbox5", vbox5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox5);
  gtk_container_add (GTK_CONTAINER (notebook1), vbox5);

  table2 = gtk_table_new (3, 4, FALSE);
  gtk_widget_ref (table2);
  gtk_object_set_data_full (GTK_OBJECT (window3), "table2", table2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table2);
  gtk_box_pack_start (GTK_BOX (vbox5), table2, TRUE, TRUE, 0);

  btnForwardLocal = gtk_toggle_button_new_with_label (_("Local"));
  gtk_widget_ref (btnForwardLocal);
  gtk_object_set_data_full (GTK_OBJECT (window3), "btnForwardLocal", btnForwardLocal,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnForwardLocal);
  gtk_table_attach (GTK_TABLE (table2), btnForwardLocal, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_button_set_relief (GTK_BUTTON (btnForwardLocal), GTK_RELIEF_NONE);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (btnForwardLocal), TRUE);

  label14 = gtk_label_new (_("Source"));
  gtk_widget_ref (label14);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label14", label14,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label14);
  gtk_table_attach (GTK_TABLE (table2), label14, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label14), 0, 0.5);

  btnForwardRemote = gtk_toggle_button_new_with_label (_("Remote"));
  gtk_widget_ref (btnForwardRemote);
  gtk_object_set_data_full (GTK_OBJECT (window3), "btnForwardRemote", btnForwardRemote,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnForwardRemote);
  gtk_table_attach (GTK_TABLE (table2), btnForwardRemote, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_button_set_relief (GTK_BUTTON (btnForwardRemote), GTK_RELIEF_NONE);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (btnForwardRemote), TRUE);

  txtForwardRemote = gtk_entry_new ();
  gtk_widget_ref (txtForwardRemote);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtForwardRemote", txtForwardRemote,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtForwardRemote);
  gtk_table_attach (GTK_TABLE (table2), txtForwardRemote, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  txtForwardLocal = gtk_entry_new ();
  gtk_widget_ref (txtForwardLocal);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtForwardLocal", txtForwardLocal,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtForwardLocal);
  gtk_table_attach (GTK_TABLE (table2), txtForwardLocal, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  txtForwardRemotePort_adj = gtk_adjustment_new (1, 1, 9999, 1, 10, 10);
  txtForwardRemotePort = gtk_spin_button_new (GTK_ADJUSTMENT (txtForwardRemotePort_adj), 1, 0);
  gtk_widget_ref (txtForwardRemotePort);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtForwardRemotePort", txtForwardRemotePort,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtForwardRemotePort);
  gtk_table_attach (GTK_TABLE (table2), txtForwardRemotePort, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  txtForwardLocalPort_adj = gtk_adjustment_new (1, 0, 9999, 1, 10, 10);
  txtForwardLocalPort = gtk_spin_button_new (GTK_ADJUSTMENT (txtForwardLocalPort_adj), 1, 0);
  gtk_widget_ref (txtForwardLocalPort);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtForwardLocalPort", txtForwardLocalPort,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtForwardLocalPort);
  gtk_table_attach (GTK_TABLE (table2), txtForwardLocalPort, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label16 = gtk_label_new (_("Port"));
  gtk_widget_ref (label16);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label16", label16,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label16);
  gtk_table_attach (GTK_TABLE (table2), label16, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label16), 0, 0.5);

  label15 = gtk_label_new (_("   Destination"));
  gtk_widget_ref (label15);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label15", label15,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label15);
  gtk_table_attach (GTK_TABLE (table2), label15, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label15), 0, 0.5);

  label33 = gtk_label_new (_("Local port"));
  gtk_widget_ref (label33);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label33", label33,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label33);
  gtk_table_attach (GTK_TABLE (table2), label33, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label33), 0, 0.5);

  txtForwardLocalPortC_adj = gtk_adjustment_new (1, 1, 9999, 1, 10, 10);
  txtForwardLocalPortC = gtk_spin_button_new (GTK_ADJUSTMENT (txtForwardLocalPortC_adj), 1, 0);
  gtk_widget_ref (txtForwardLocalPortC);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtForwardLocalPortC", txtForwardLocalPortC,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtForwardLocalPortC);
  gtk_table_attach (GTK_TABLE (table2), txtForwardLocalPortC, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (txtForwardLocalPortC), TRUE);

  txtForwardRemotePortC_adj = gtk_adjustment_new (1, 1, 100, 1, 10, 10);
  txtForwardRemotePortC = gtk_spin_button_new (GTK_ADJUSTMENT (txtForwardRemotePortC_adj), 1, 0);
  gtk_widget_ref (txtForwardRemotePortC);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtForwardRemotePortC", txtForwardRemotePortC,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtForwardRemotePortC);
  gtk_table_attach (GTK_TABLE (table2), txtForwardRemotePortC, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (txtForwardRemotePortC), TRUE);

  table3 = gtk_table_new (4, 2, FALSE);
  gtk_widget_ref (table3);
  gtk_object_set_data_full (GTK_OBJECT (window3), "table3", table3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table3);
  gtk_box_pack_start (GTK_BOX (vbox5), table3, TRUE, TRUE, 0);

  label17 = gtk_label_new (_("X11 Forwarding"));
  gtk_widget_ref (label17);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label17", label17,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label17);
  gtk_table_attach (GTK_TABLE (table3), label17, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label17), 0, 0.5);

  label18 = gtk_label_new (_("Authentication agent forwarding"));
  gtk_widget_ref (label18);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label18", label18,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label18);
  gtk_table_attach (GTK_TABLE (table3), label18, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label18), 0, 0.5);

  lstX11Forward = gtk_combo_new ();
  gtk_widget_ref (lstX11Forward);
  gtk_object_set_data_full (GTK_OBJECT (window3), "lstX11Forward", lstX11Forward,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lstX11Forward);
  gtk_table_attach (GTK_TABLE (table3), lstX11Forward, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_combo_set_value_in_list (GTK_COMBO (lstX11Forward), TRUE, FALSE);
  lstX11Forward_items = g_list_append (lstX11Forward_items, (gpointer) _("Default"));
  lstX11Forward_items = g_list_append (lstX11Forward_items, (gpointer) _("Enabled"));
  lstX11Forward_items = g_list_append (lstX11Forward_items, (gpointer) _("Disabled"));
  gtk_combo_set_popdown_strings (GTK_COMBO (lstX11Forward), lstX11Forward_items);
  g_list_free (lstX11Forward_items);

  txtX11 = GTK_COMBO (lstX11Forward)->entry;
  gtk_widget_ref (txtX11);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtX11", txtX11,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtX11);
  gtk_entry_set_editable (GTK_ENTRY (txtX11), FALSE);
  gtk_entry_set_text (GTK_ENTRY (txtX11), _("Default"));

  lstAuthForward = gtk_combo_new ();
  gtk_widget_ref (lstAuthForward);
  gtk_object_set_data_full (GTK_OBJECT (window3), "lstAuthForward", lstAuthForward,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lstAuthForward);
  gtk_table_attach (GTK_TABLE (table3), lstAuthForward, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_combo_set_value_in_list (GTK_COMBO (lstAuthForward), TRUE, FALSE);
  lstAuthForward_items = g_list_append (lstAuthForward_items, (gpointer) _("Default"));
  lstAuthForward_items = g_list_append (lstAuthForward_items, (gpointer) _("Enabled"));
  lstAuthForward_items = g_list_append (lstAuthForward_items, (gpointer) _("Disabled"));
  gtk_combo_set_popdown_strings (GTK_COMBO (lstAuthForward), lstAuthForward_items);
  g_list_free (lstAuthForward_items);

  txtAuth = GTK_COMBO (lstAuthForward)->entry;
  gtk_widget_ref (txtAuth);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtAuth", txtAuth,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtAuth);
  gtk_entry_set_editable (GTK_ENTRY (txtAuth), FALSE);
  gtk_entry_set_text (GTK_ENTRY (txtAuth), _("Default"));

  label19 = gtk_label_new (_("Allow remote hosts to connect\nto locally forwarded ports"));
  gtk_widget_ref (label19);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label19", label19,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label19);
  gtk_table_attach (GTK_TABLE (table3), label19, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label19), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label19), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label19), 0, 1);

  chkAllowRemote = gtk_check_button_new_with_label (_("Yes"));
  gtk_widget_ref (chkAllowRemote);
  gtk_object_set_data_full (GTK_OBJECT (window3), "chkAllowRemote", chkAllowRemote,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkAllowRemote);
  gtk_table_attach (GTK_TABLE (table3), chkAllowRemote, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label23 = gtk_label_new (_("Kerberos ticket and AFS token\nforwarding"));
  gtk_widget_ref (label23);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label23", label23,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label23);
  gtk_table_attach (GTK_TABLE (table3), label23, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label23), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label23), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label23), 0, 1);

  chkDisableKerberos = gtk_check_button_new_with_label (_("Disable"));
  gtk_widget_ref (chkDisableKerberos);
  gtk_object_set_data_full (GTK_OBJECT (window3), "chkDisableKerberos", chkDisableKerberos,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkDisableKerberos);
  gtk_table_attach (GTK_TABLE (table3), chkDisableKerberos, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label9 = gtk_label_new (_("Forwarding"));
  gtk_widget_ref (label9);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label9", label9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label9);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 1), label9);

  table4 = gtk_table_new (7, 2, FALSE);
  gtk_widget_ref (table4);
  gtk_object_set_data_full (GTK_OBJECT (window3), "table4", table4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table4);
  gtk_container_add (GTK_CONTAINER (notebook1), table4);

  label21 = gtk_label_new (_("Cipher type"));
  gtk_widget_ref (label21);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label21", label21,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label21);
  gtk_table_attach (GTK_TABLE (table4), label21, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label21), 0, 0.5);

  lstCipherType = gtk_combo_new ();
  gtk_widget_ref (lstCipherType);
  gtk_object_set_data_full (GTK_OBJECT (window3), "lstCipherType", lstCipherType,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lstCipherType);
  gtk_table_attach (GTK_TABLE (table4), lstCipherType, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_combo_set_value_in_list (GTK_COMBO (lstCipherType), TRUE, FALSE);
  lstCipherType_items = g_list_append (lstCipherType_items, (gpointer) _("Default"));
  lstCipherType_items = g_list_append (lstCipherType_items, (gpointer) _("3des"));
  lstCipherType_items = g_list_append (lstCipherType_items, (gpointer) _("blowfish"));
  gtk_combo_set_popdown_strings (GTK_COMBO (lstCipherType), lstCipherType_items);
  g_list_free (lstCipherType_items);

  txtCipher = GTK_COMBO (lstCipherType)->entry;
  gtk_widget_ref (txtCipher);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtCipher", txtCipher,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtCipher);
  gtk_entry_set_editable (GTK_ENTRY (txtCipher), FALSE);
  gtk_entry_set_text (GTK_ENTRY (txtCipher), _("Default"));

  togglebutton4 = gtk_toggle_button_new_with_label (_("Custom escape character"));
  gtk_widget_ref (togglebutton4);
  gtk_object_set_data_full (GTK_OBJECT (window3), "togglebutton4", togglebutton4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (togglebutton4);
  gtk_table_attach (GTK_TABLE (table4), togglebutton4, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_button_set_relief (GTK_BUTTON (togglebutton4), GTK_RELIEF_NONE);

  txtEscape = gtk_entry_new_with_max_length (1);
  gtk_widget_ref (txtEscape);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtEscape", txtEscape,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtEscape);
  gtk_table_attach (GTK_TABLE (table4), txtEscape, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_text (GTK_ENTRY (txtEscape), _("~"));

  label22 = gtk_label_new (_("Identity file"));
  gtk_widget_ref (label22);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label22", label22,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label22);
  gtk_table_attach (GTK_TABLE (table4), label22, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label22), 0, 0.5);

  txtIdFile = gnome_file_entry_new (NULL, _("Select identity file"));
  gtk_widget_ref (txtIdFile);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtIdFile", txtIdFile,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtIdFile);
  gtk_table_attach (GTK_TABLE (table4), txtIdFile, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_container_set_border_width (GTK_CONTAINER (txtIdFile), 1);
  gnome_entry_set_max_saved (GNOME_ENTRY (GNOME_FILE_ENTRY (txtIdFile)->gentry), 3);
  gnome_file_entry_set_modal (GNOME_FILE_ENTRY (txtIdFile), TRUE);

  txtIdent = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (txtIdFile));
  gtk_widget_ref (txtIdent);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtIdent", txtIdent,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtIdent);

  label24 = gtk_label_new (_("Outgoing connections"));
  gtk_widget_ref (label24);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label24", label24,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label24);
  gtk_table_attach (GTK_TABLE (table4), label24, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label24), 0, 0.5);

  chkNonprivPort = gtk_check_button_new_with_label (_("Use non-privileged port"));
  gtk_widget_ref (chkNonprivPort);
  gtk_object_set_data_full (GTK_OBJECT (window3), "chkNonprivPort", chkNonprivPort,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkNonprivPort);
  gtk_table_attach (GTK_TABLE (table4), chkNonprivPort, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label25 = gtk_label_new (_("Pseudo-tty allocation"));
  gtk_widget_ref (label25);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label25", label25,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label25);
  gtk_table_attach (GTK_TABLE (table4), label25, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label25), 0, 0.5);

  lstPseudoTty = gtk_combo_new ();
  gtk_widget_ref (lstPseudoTty);
  gtk_object_set_data_full (GTK_OBJECT (window3), "lstPseudoTty", lstPseudoTty,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (lstPseudoTty);
  gtk_table_attach (GTK_TABLE (table4), lstPseudoTty, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  lstPseudoTty_items = g_list_append (lstPseudoTty_items, (gpointer) _("Default"));
  lstPseudoTty_items = g_list_append (lstPseudoTty_items, (gpointer) _("Force"));
  lstPseudoTty_items = g_list_append (lstPseudoTty_items, (gpointer) _("Disable"));
  gtk_combo_set_popdown_strings (GTK_COMBO (lstPseudoTty), lstPseudoTty_items);
  g_list_free (lstPseudoTty_items);

  txtPseudoTTY = GTK_COMBO (lstPseudoTty)->entry;
  gtk_widget_ref (txtPseudoTTY);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtPseudoTTY", txtPseudoTTY,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtPseudoTTY);
  gtk_entry_set_text (GTK_ENTRY (txtPseudoTTY), _("Default"));

  label26 = gtk_label_new (_("Compression"));
  gtk_widget_ref (label26);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label26", label26,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label26);
  gtk_table_attach (GTK_TABLE (table4), label26, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label26), 0, 0.5);

  chkCompression = gtk_check_button_new_with_label (_("Request compression of all data"));
  gtk_widget_ref (chkCompression);
  gtk_object_set_data_full (GTK_OBJECT (window3), "chkCompression", chkCompression,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkCompression);
  gtk_table_attach (GTK_TABLE (table4), chkCompression, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label27 = gtk_label_new (_("Custom options"));
  gtk_widget_ref (label27);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label27", label27,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label27);
  gtk_table_attach (GTK_TABLE (table4), label27, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label27), 0, 0.5);

  txtCustom = gtk_entry_new ();
  gtk_widget_ref (txtCustom);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtCustom", txtCustom,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtCustom);
  gtk_table_attach (GTK_TABLE (table4), txtCustom, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label20 = gtk_label_new (_("Protocol"));
  gtk_widget_ref (label20);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label20", label20,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label20);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 2), label20);

  table5 = gtk_table_new (4, 2, FALSE);
  gtk_widget_ref (table5);
  gtk_object_set_data_full (GTK_OBJECT (window3), "table5", table5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table5);
  gtk_container_add (GTK_CONTAINER (notebook1), table5);

  label29 = gtk_label_new (_("Fork to background\nbefore command\nexecution"));
  gtk_widget_ref (label29);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label29", label29,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label29);
  gtk_table_attach (GTK_TABLE (table5), label29, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label29), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label29), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label29), 0, 2);

  chkFork = gtk_check_button_new_with_label (_("Yes"));
  gtk_widget_ref (chkFork);
  gtk_object_set_data_full (GTK_OBJECT (window3), "chkFork", chkFork,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkFork);
  gtk_table_attach (GTK_TABLE (table5), chkFork, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label30 = gtk_label_new (_("Redirect input\nfrom /dev/null"));
  gtk_widget_ref (label30);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label30", label30,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label30);
  gtk_table_attach (GTK_TABLE (table5), label30, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label30), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label30), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label30), 0, 2);

  chkDevNull = gtk_check_button_new_with_label (_("Yes"));
  gtk_widget_ref (chkDevNull);
  gtk_object_set_data_full (GTK_OBJECT (window3), "chkDevNull", chkDevNull,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkDevNull);
  gtk_table_attach (GTK_TABLE (table5), chkDevNull, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label31 = gtk_label_new (_("Execute remote\ncommand"));
  gtk_widget_ref (label31);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label31", label31,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label31);
  gtk_table_attach (GTK_TABLE (table5), label31, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label31), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label31), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label31), 0, 2);

  chkExecCmd = gtk_check_button_new_with_label (_("No"));
  gtk_widget_ref (chkExecCmd);
  gtk_object_set_data_full (GTK_OBJECT (window3), "chkExecCmd", chkExecCmd,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (chkExecCmd);
  gtk_table_attach (GTK_TABLE (table5), chkExecCmd, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label32 = gtk_label_new (_("Execute command"));
  gtk_widget_ref (label32);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label32", label32,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label32);
  gtk_table_attach (GTK_TABLE (table5), label32, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label32), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label32), 0, 2);

  txtExecCmd = gtk_entry_new ();
  gtk_widget_ref (txtExecCmd);
  gtk_object_set_data_full (GTK_OBJECT (window3), "txtExecCmd", txtExecCmd,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (txtExecCmd);
  gtk_table_attach (GTK_TABLE (table5), txtExecCmd, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label28 = gtk_label_new (_("Command execution"));
  gtk_widget_ref (label28);
  gtk_object_set_data_full (GTK_OBJECT (window3), "label28", label28,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label28);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 3), label28);

  btnSettingsOk = gnome_stock_button (GNOME_STOCK_BUTTON_OK);
  gtk_widget_ref (btnSettingsOk);
  gtk_object_set_data_full (GTK_OBJECT (window3), "btnSettingsOk", btnSettingsOk,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnSettingsOk);
  gtk_packer_add_defaults (GTK_PACKER (packer12), btnSettingsOk, GTK_SIDE_BOTTOM,
                           GTK_ANCHOR_EAST, (GtkPackerOptions) (GTK_FILL_X));

  btnSettingsCancel = gnome_stock_button (GNOME_STOCK_BUTTON_CANCEL);
  gtk_widget_ref (btnSettingsCancel);
  gtk_object_set_data_full (GTK_OBJECT (window3), "btnSettingsCancel", btnSettingsCancel,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (btnSettingsCancel);
  gtk_packer_add_defaults (GTK_PACKER (packer12), btnSettingsCancel, GTK_SIDE_BOTTOM,
                           GTK_ANCHOR_WEST, (GtkPackerOptions) (GTK_FILL_X));

  gtk_signal_connect (GTK_OBJECT (window3), "delete_event",
                      GTK_SIGNAL_FUNC (on_window_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnSettingsOk), "clicked",
                      GTK_SIGNAL_FUNC (on_btnSettingsOk_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (btnSettingsCancel), "clicked",
                      GTK_SIGNAL_FUNC (on_btnSettingsCancel_clicked),
                      NULL);

  return window3;
}

