#ifndef GSSH_UTILS_H
#define GSSH_UTILS_H

void updateComboBox(void);
void updateHostBox(void);
int hostList_addEntry(char **entry,int position);
int openTerminal(char *host, char *user,int port,Options *opts,int pos);
char *sshExtraOptions(SSH_Entry *opts);

#endif
