/* Automatically generated by po2tbl.sed from gssh.pot.  */

#if HAVE_CONFIG_H
# include <config.h>
#endif

#include "libgettext.h"

const struct _msg_ent _msg_tbl[] = {
  {"", 1},
  {"gssh", 2},
  {"Hostname:", 3},
  {"localhost", 4},
  {"Username:", 5},
  {"Use port:", 6},
  {"Options", 7},
  {"Connect", 8},
  {"About gssh", 9},
  {"Quit", 10},
  {"\
A front end to ssh.\n\
Appearance made to mimic kssh", 11},
  {"gssh options", 12},
  {"Host", 13},
  {"Host list", 14},
  {"Add", 15},
  {"Remove", 16},
  {"Host settings", 17},
  {"Ssh command:", 18},
  {"ssh", 19},
  {"Terminal", 20},
  {"gnome-terminal", 21},
  {"Save host name", 22},
  {"Save host settings", 23},
  {"Use host settings", 24},
  {"Replace", 25},
  {"Append", 26},
  {"Import from kssh", 27},
  {"Settings", 28},
  {"Username      ", 29},
  {"Extra settings", 30},
  {"Use port", 31},
  {"Enable", 32},
  {"\
Note ! If you want to use the extra\n\
features on the other pages, be sure to\n\
enable the 'Extra settings' checkbox above !", 33},
  {"Basic", 34},
  {"Local", 35},
  {"Source", 36},
  {"Remote", 37},
  {"Port", 38},
  {"   Destination", 39},
  {"Local port", 40},
  {"X11 Forwarding", 41},
  {"Authentication agent forwarding", 42},
  {"Default", 43},
  {"Enabled", 44},
  {"Disabled", 45},
  {"\
Allow remote hosts to connect\n\
to locally forwarded ports", 46},
  {"Yes", 47},
  {"\
Kerberos ticket and AFS token\n\
forwarding", 48},
  {"Disable", 49},
  {"Forwarding", 50},
  {"Cipher type", 51},
  {"3des", 52},
  {"blowfish", 53},
  {"Custom escape character", 54},
  {"~", 55},
  {"Identity file", 56},
  {"Select identity file", 57},
  {"Outgoing connections", 58},
  {"Use non-privileged port", 59},
  {"Pseudo-tty allocation", 60},
  {"Force", 61},
  {"Compression", 62},
  {"Request compression of all data", 63},
  {"Custom options", 64},
  {"Protocol", 65},
  {"\
Fork to background\n\
before command\n\
execution", 66},
  {"\
Redirect input\n\
from /dev/null", 67},
  {"\
Execute remote\n\
command", 68},
  {"No", 69},
  {"Execute command", 70},
  {"Command execution", 71},
  {"Couldn't find pixmap file: %s", 72},
  {"Couldn't create pixmap from file: %s", 73},
};

int _msg_tbl_length = 73;
