#include <gnome.h>


void
exit_app	                       (GtkObject       *object,
                                        gpointer         user_data);

void on_exit_app();

void
on_btnAbout_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_btnOptions_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_btnAdd_clicked                      (GtkButton       *button,
                                        gpointer         user_data);

void
on_btnRemove_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_btnUp_clicked                       (GtkButton       *button,
                                        gpointer         user_data);

void
on_btnDown_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_btnCancelConf_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_lstHosts_select_row                 (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_btnImport_clicked                   (GtkWidget       *button,
                                        gpointer         user_data);

void
on_btnOkConf_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_btnConnect_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_txtHostname_changed                 (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_btnHostSettings_clicked             (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_window_delete_event                (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);


void
on_btnSettingsOk_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_btnSettingsCancel_clicked           (GtkButton       *button,
                                        gpointer         user_data);
